TITLE     'Pressure-Driven Flow through a Channel'	          { sim212.pde }
SELECT     errlim=1e-5  nodelimit=800   spectral_colors 	
VARIABLES     vx     vy     p
DEFINITIONS
   Lx=1.0     Ly=1.0     visc=1e4     delp=1e2		{ Driving pressure }
   vx_ex=delp/(2*Lx)/(2*visc)*(Ly^2- y^2)			{ Exact solution }
   dens=1e3     Re=dens*globalmax( vx)*2*Ly/visc	
   v=vector( vx, vy)     vm=magnitude( v)			{ Speed }
EQUATIONS     							{ For vanishing Re }
   vx:	dx( p)- visc*div( grad( vx))=0
   vy:	dy( p)- visc*div( grad( vy))=0
   p:	div( grad( p))=0				{ Divergence term neglected }
BOUNDARIES
region 'domain'
   start 'outer' (-Lx,Ly)
   natural( vx)=0   value( vy)=0    value(p)=delp			{ In }
   line to (-Lx,-Ly)  value( vx)=0   value( vy)=0
   natural(p)=-visc*div( grad( vy))
   line to (Lx,-Ly) natural( vx)=0   value( vy)=0   value(p)=0  	{ Out }
   line to (Lx,Ly)   value( vx)=0   value( vy)=0
   natural(p)=visc*div(grad( vy))
   line to close
PLOTS
   elevation( vx, vy) on 'outer' report( Re)		
   contour( vx)     contour( vy)     contour( p)
   vector( v) norm
   contour( div( v))     contour( curl( v)) painted
   contour( vx- vx_ex ) report( globalmax( vx))
END

