TITLE     'Drag and Lift on an Inclined Plate'                       { sim222.pde }
SELECT     errlim=1e-3     ngrid=1  nodelimit=2000   spectral_colors
VARIABLES     vx      vy       p
DEFINITIONS
   Lx=1.0     Ly=1.0     a=0.5     d=0.1     visc=1.0
{ Geometric parameters for inclined plate }
      alpha=30* pi/180     			{ Angle of attack, radians }
      si=sin( alpha)     co=cos( alpha)
      x1=-d/2*si- a/2*co     y1=-d/2*co+ a/2*si
      x2=d/2*si- a/2*co     y2=d/2*co+ a/2*si
      x3=-x1     y3=-y1     x4=-x2     y4=-y2               	
   delp=1e-5							{ Driving pressure }
   dens=1e3     Re=dens*globalmax( vx)*2*Lx/visc	
#include 'visc_xy.pde'
EQUATIONS
   vx:		dx( p)- visc*div( grad( vx))=0
   vy:		dy( p)- visc*div( grad( vy))=0
   p:		div( grad( p))- 1e4*visc/Ly^2*div( v)=0
BOUNDARIES
region 'domain'  start 'outer' (-Lx,Ly)
   natural( vx)=0   natural( vy)=0    value(p)=delp			{ In }
   line to (-Lx,-Ly)   natural( vx)=0   value( vy)=0   natural(p)=0
   line to (Lx,-Ly)  natural( vx)=0   natural( vy)=0   value(p)=0  	{ Out }
   line to (Lx,Ly)   natural( vx)=0   value( vy)=0   natural(p)=0	
   line to close
   start 'outline' (x1,y1) 					{ Exclude }
   value( vx)=0  value( vy)=0   natural(p)=0	
   line to (x2,y2) to (x3,y3) to (x4,y4) to close
PLOTS
   contour( vx) report( Re)     contour( vm) painted     vector( v) norm
   contour( p) painted
   elevation( visc*dy( vx)) from (-Lx,-Ly) to (Lx,-Ly)	{ Fx on ''wall'' }
   elevation( p) from (-Lx,-Ly) to (Lx,-Ly)		{ Force_y on liquid }
   elevation( p) from (-Lx,Ly) to (Lx,Ly)
   elevation( -p*normal( unit_y)) on 'outer'   	{ Total Fy on plate }
END



