TITLE     'Flow past an Inclined Plate, Forces'		         { sim244.pde }
SELECT     stages=6     ngrid=1  nodelimit=1000   spectral_colors
VARIABLES     vx     vy     p
DEFINITIONS
   Lx=1.5     Ly=1.5     a=1.0     d=0.2
   alpha=30*pi/180     				{ Angle of attack, radians }
   si=sin( alpha)     co=cos( alpha)
   x1=-d/2*si- a/2*co     y1=-d/2*co+ a/2*si
   x2=d/2*si- a/2*co     y2=d/2*co+ a/2*si
   x3=-x1     y3=-y1     x4=-x2     y4=-y2               	
   visc=1.0     delp=staged(1e-5, 0.03, 0.1, 0.2, 0.4, 0.4)
   dens=1e3     MRe=dens*globalmax( vx)*a/visc	
   v=vector( vx, vy)     vm=magnitude( v)
   unit_x=vector(1,0)     unit_y=vector(0,1)
   nx=normal( unit_x)     ny=normal( unit_y)
   vxdvx=vx*dx(  vx)+ vy*dy( vx)     vxdvy=vx*dx( vy)+ vy*dy( vy)
   natp=    if stage=6 then visc*( nx*div( grad( vx))+ ny*div( grad( vy)))
      -dens*( nx*vxdvx+  ny*vxdvy)   else 0
   dens_term=    if stage=6 then dens*( dx( vxdvx)+ dy( vxdvy))  else 0
EQUATIONS
   vx:		dens*vxdvx+ dx( p)- visc*div( grad( vx))=0
   vy:		dens*vxdvy+ dy( p)- visc*div( grad( vy))=0
   p:		div( grad( p))+ dens_term- 1e4*visc/Ly^2*div( v)=0
BOUNDARIES	region 'domain'  start 'outer' (-Lx,Ly)
   natural( vx)=0   natural( vy)=0    value(p)=delp			  { In }
   line to (-Lx,-Ly)   natural( vx)=0   value( vy)=0   natural(p)=natp { Slip }
   line to (4*Lx,-Ly)  natural( vx)=0   natural( vy)=0   value(p)=0  	  { Out }
   line to (4*Lx,Ly)   natural( vx)=0   value( vy)=0   natural(p)=natp { Slip }
   line to close
   start 'outline' (x1,y1)						{ Exclude plate }
   value( vx)=0  value( vy)=0   natural(p)=natp	
   line to (x2,y2) to (x3,y3) to (x4,y4) to close
PLOTS
   contour( vx/delp) report(MRe)     contour( vm) painted report(MRe)
   vector( v) norm zoom( -a/2,-a,  2*a,2*a)
   contour( p) painted report(delp*2*Ly) 				{ Force_x }
   elevation( -p*normal( unit_y)) on 'outer' report(delp*2*Ly) 	{ p.288 }
END

