TITLE   'Flow through a Box with Two Orifices'                   { sim253.pde }
SELECT     errlim=1e-3     ngrid=2  nodelimit=2000   spectral_colors
COORDINATES     cartesian3	
VARIABLES     vx     vy     vz     p
DEFINITIONS
   Lx=3.0     Ly=2.0     Lz=2.0     r0=1.0     visc=1e4     delp=1e2
   dens=1e3     Re=dens*globalmax( vz)*2*Ly/visc	
   v=vector( vx, vy, vz)     vm=magnitude( v)
   unit_x=vector(1,0,0)     unit_y=vector(0,1,0)     unit_z=vector(0,0,1)
   nx=normal( unit_x)     ny=normal( unit_y)     nz=normal( unit_z)
   natp=0   							{ Simplified natural(p) }
EQUATIONS						{ For Re<<1 }
   vx:		dx( p)- visc*div( grad( vx))=0
   vy:		dy( p)- visc*div( grad( vy))=0
   vz:		dz( p)- visc*div( grad( vz))=0
   p:		div( grad( p))- 1e4*visc/Lx^2*div( v)=0
EXTRUSION						{ Parallel surfaces }
   surface 'bottom' z=-Lz	
   layer 'liquid'						{ Layer containing liquid }
   surface 'top' z=Lz
BOUNDARIES
   surface 'bottom'   value( vx)=0   value( vy)=0   value( vz)=0
      natural( p)=natp					
   surface 'top'   value( vx)=0   value( vy)=0   value( vz)=0
      natural( p)=natp					
region 'box'							{ Full solution domain }	
   start 'outer' (-Lx,-Ly)
   value( vx)=0   value( vy)=0   value( vz)=0   natural( p)=natp
   line to (Lx,-Ly)  to (Lx,Ly)  to (-Lx,Ly)  close
region 'in'
   surface 'bottom'   natural( vx)=0   natural( vy)=0   natural( vz)=0
      value( p)=delp
   start (-2.5,-0.5)  arc( center=-1.5,-0.5) angle=360
region 'out'
   surface 'top'   natural( vx)=0   natural( vy)=0   natural( vz)=0
      value( p)=0
   start (2.5,0.5)  arc( center=1.5,0.5) angle=360
MONITORS
   contour( p) painted on z=-Lz report(Re)
   contour( p) painted on z=Lz
   contour( vm) painted on z=0   contour( vm) painted on x=0
PLOTS
   contour( p) painted on z=-Lz report(Re)
   contour( vz) painted on z=-Lz     contour( vz) painted on z=Lz
   vector( v) norm  on y=0     vector( v) norm on y=2/3*x
   vector( v) norm on x=-2.0     vector( v) norm on x=2.0
END

