TITLE   'Flow around a Cubical Obstacle'                           { sim254.pde }
SELECT     errlim=1e-3     ngrid=2  nodelimit=2000   spectral_colors
COORDINATES     cartesian3	
VARIABLES     vx     vy     vz     p
DEFINITIONS
   r0=1.0     Lc=0.3     Lz=3.0     visc=1e4     delp=1e2
   dens=1e3     Re=dens*globalmax( vz)*2*r0/visc	
   v=vector( vx, vy, vz)     vm=magnitude( v)
   unit_x=vector(1,0,0)     unit_y=vector(0,1,0)     unit_z=vector(0,0,1)
   nx=normal( unit_x)     ny=normal( unit_y)     nz=normal( unit_z)
   natp=0  							{ Simplified}
EQUATIONS						{ For Re<<1 }
   vx:		dx( p)- visc*div( grad( vx))=0
   vy:		dy( p)- visc*div( grad( vy))=0
   vz:		dz( p)- visc*div( grad( vz))=0
   p:		div( grad( p))- 1e4*visc/r0^2*div( v)=0	{ Tube radius r0 }
EXTRUSION						{ Parallel surfaces }
   surface 'bottom' z=-Lz	
   layer '1'							{ Three liquid layers, 1-3 }
   surface 'low' z=-Lc
   layer '2'	
   surface 'high' z=Lc
   layer '3'						
   surface 'top' z=Lz
BOUNDARIES
   surface 'bottom'  natural(vx)=0    natural(vy)=0   natural(vz)=0
      value(p)=delp
   surface 'top'    natural(vx)=0    natural(vy)=0   natural(vz)=0
   value(p)=0
region 'domain'				{ Full solution domain }	
   start (r0,0)   value( vx)=0   value( vy)=0   value( vz)=0
   natural( p)=natp		
   arc( center=0,0) angle=360
region 'cube'
   surface 'low' value(vx)=0   value(vy)=0   value(vz)=0
       natural(p)=natp			{ Surfaces pertaining to cube }
   surface 'high'   value(vx)=0   value(vy)=0   value(vz)=0
       natural(p)=natp
   layer '2' void				{ Cube excluded from domain }
   start (-Lc,-Lc) layer '2'   value(vx)=0   value(vy)=0   value(vz)=0
   natural(p)=natp				{ These BCs limited to layer 2 }
   line to (Lc,-Lc) to (Lc,Lc) to (-Lc,Lc) close
MONITORS
   contour( vm) painted on z=0     contour( vm) painted on x=0
PLOTS
   contour( p) painted on x=0 report(Re)
   contour( vz) painted on x=0     contour( vz) painted on y=0
   contour( vz) painted on z=-Lz     contour( vz) painted on z=0
   contour( vz) painted on z=Lz
   vector( v) norm on x=0 zoom(-r0,-r0, 2*r0,2*r0)
   elevation( p) from (0,0,-Lz) to (0,0,Lz)
   elevation( vz) from (0,0,-Lz) to (0,0,Lz)
END

