TITLE   'Viscous Flow through a Funnel'                             { sim255.pde }
SELECT     errlim=5e-3     ngrid=2  nodelimit=2000   spectral_colors
COORDINATES     cartesian3	
VARIABLES     vx     vy     vz     p
DEFINITIONS
   r0=1.0     r1=3.0     L=2.0     visc=1e4     delp=1e5
   dens=1e3     g=9.81      Fz=-dens*g		{Force due to gravity }
   Re=dens*globalmax( vz)*2*r0/visc	
   v=vector( vx, vy, vz)     vm=magnitude( v)
   rad=max( r0, sqrt( x^2+y^2))
   zfun=L+L*(rad-r0)/(r1-r0)
   unit_x=vector(1,0,0)     unit_y=vector(0,1,0)     unit_z=vector(0,0,1)
   nx=normal( unit_x)     ny=normal( unit_y)     nz=normal( unit_z)
   natp=nz*Fz						{ Simplified }
EQUATIONS						{ For Re<<1 }
   vx:		dx( p)- visc*div( grad( vx))=0
   vy:		dy( p)- visc*div( grad( vy))=0
   vz:		dz( p)- Fz- visc*div( grad( vz))=0
   p:		div( grad( p))- 1e4*visc/r0^2*div( v)=0	{ Tube radius r0 }
EXTRUSION							
   surface '1' z=0	
   layer 'lower' 										
   surface '2' z=zfun
   layer 'upper'
   surface '3' z=2*L
BOUNDARIES
   surface '1'  natural(vx)=0   natural(vy)=0   natural(vz)=0   value( p)=0
   surface '3'  natural(vx)=0   natural(vy)=0  natural(vz)=0   value( p)=delp
region 'domain'    					{ Outer region }	
   layer 'lower'  void					{ Empty space }
   surface '2' value(vx)=0   value(vy)=0   value(vz)=0   natural(p)=natp
   layer 'upper'		
   start 'outer' (r1,0)  arc( center=0,0) angle=360
limited region 'cylinder'			{ Limited to the lower layer }	
   layer 'lower'					{ Redefine void as visc }	
   start (r0,0) layer 'lower'
   value(vx)=0   value(vy)=0   value(vz)=0   natural(p)=natp
   arc( center=0,0) angle=360
MONITORS
   contour( vz) painted on x=0
PLOTS
   grid( x, y, z)     grid( y, z) on x=0
   contour( vz) painted on x=0     contour( vm) painted on x=0
   vector( v) norm on x=0     contour( p) painted on x=0
   contour( vz) painted on z=0.01     contour( vz) painted on z=0.99*L
   contour( vz) painted on z=1.01*L     contour( vz) painted on z=1.95*L
END

