TITLE   'Seeping through Plate and Pillar'                           { sim256.pde }
SELECT     errlim=1e-4     ngrid=2  nodelimit=2000   spectral_colors
COORDINATES     cartesian3	
VARIABLES     vx     vy     vz     p
DEFINITIONS
   L=1.0     r0=0.15     z0=0.2
   visc=1e-3     k=1e-12     delp=1e4
   dens=1e3    Fgz=-dens*9.81 	
   v=vector( vx, vy, vz)     vm=magnitude( v)
   unit_x=vector(1,0,0)     unit_y=vector(0,1,0)     unit_z=vector(0,0,1)
   nx=normal( unit_x)     ny=normal( unit_y)     nz=normal( unit_z)
   natp=nz*Fgz- visc/k*( nx*vx+ ny*vy+ nz*vz)
EQUATIONS						{ For Re<<1 }
   vx:		dx( p)+ visc/k*vx=0
   vy:		dy( p)+ visc/k*vy=0
   vz:		dz( p)- Fgz+ visc/k*vz=0
   p:		div( grad( p))- 1e4*visc/r0^2*div( v)=0
EXTRUSION						{ Parallel surfaces }
   surface 'bottom' z=0	
   layer 'plate'	 					
   surface 'middle' z=z0					{ Interface }
   layer 'pillar'						
   surface 'top' z=L
BOUNDARIES
   surface 'bottom'
   natural(vx)=0   natural(vy)=0   natural(vz)=0   value(p)=delp
   surface 'top'
   natural(vx)=0   natural(vy)=0   natural(vz)=0   value(p)=0
region 'domain'    					{ Full solution domain }	
   layer 'pillar'  void				{ Exclude space outside pillar }
   surface 'middle' 					{ Upper surface of plate }
   natural(vx)=0   natural(vy)=0   value(vz)=0   natural(p)=natp
   start 'outer' (0,0)	{ Rectangle to be extruded, impermeable sides }
   value(vx)=0   value(vy)=0   natural(vz)=0   natural(p)=natp
   line to (L,0)  to (L,L) to (0,L)  close
region 'cylinder'   start (L/3+r0,L/3)
   layer 'pillar'   value(vx)=0   value(vy)=0   natural(vz)=0   natural(p)=natp
   arc( center=L/3,L/3) angle=360
MONITORS
   contour( vm) painted on x=L/3
PLOTS
   contour( vz) painted on z=z0/2     contour( vz) painted on z=L
   contour( vm) painted on x=L/3     vector( v) norm on x=L/3
   contour( p) painted on x=L/3
END

